// CannonView.h
// CannonView's interface declaration
// Implementation in CannonView.m
#import <UIKit/UIKit.h>
#import <AVFoundation/AVFoundation.h>
#define TARGET_PIECES 7 // number of sections in the target

typedef struct line // groups two points that represent a line
{
   CGPoint start; // the line's start point
   CGPoint end; // the line's end point
} Line; // end typedef struct line

@interface CannonView : UIView
{
   AVAudioPlayer *cannonFireSound; // plays the cannon firing sound
   AVAudioPlayer *targetHitSound; // plays the target hit sound
   AVAudioPlayer *blockerHitSound; // plays the blocker hit sound
   
   Line blocker; // stores the points representing the blocker
   Line target; // stores the points representing the target
   BOOL targetPieceHit[TARGET_PIECES]; // is each target piece hit?
   int targetPiecesHit; // number of target pieces hit
   float blockerVelocity; // blocker's velocity
   float targetVelocity; // target's velocity
   
   CGPoint cannonball; // cannonball image's upper-left corner
   CGPoint cannonballVelocity; // cannonball's velocity
   CGPoint barrelEnd; // the endpoint of the cannon's barrel
   NSTimer *timer; // the main timer
   BOOL cannonballOnScreen; // is the cannonball on the screen?
   
   int timerCount; // times the timer fired since the last second
   int timeLeft; // the amount of time left in seconds
   int shotsFired; // the number of shots the user has made
   int timeElapsed; // the number of seconds elapsed
} // end instance variable declaration

- (void)timerFired:(NSTimer *)theTimer; // updates the entire display

// shows and alert with the given title and message
- (void)showAlertWithTitle:(NSString *)title message:(NSString *)message;
- (void)newGame; // starts a new game
- (void)processTouch:(UITouch *)touch; // process a player's touch
@end // end interface CannonView


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

