// ContactViewController.m
// Implementation of ContactViewController.
#import "ContactViewController.h"

@implementation ContactViewController

@synthesize person; // generate get and set methods for person 

// setup the view once it's loaded
- (void)viewDidLoad
{
   // create the button for sending a contact
   UIBarButtonItem *sendButton = [[UIBarButtonItem alloc]
      initWithBarButtonSystemItem:UIBarButtonSystemItemAction target:self
      action:@selector(send)];
   [self.navigationItem setRightBarButtonItem:sendButton];
} // end method viewDidLoad

// displays a list of other iPhones to send this contact to
- (void)send
{
   // create a new GKPeerPickerController for connecting to a peer
   GKPeerPickerController *peerPicker =
      [[GKPeerPickerController alloc] init];
   peerPicker.delegate = self;
   peerPicker.connectionTypesMask = GKPeerPickerConnectionTypeNearby;
   [peerPicker show]; // show the peer picker
} // end method send

// called when the user chooses a peer to send this contact to
- (void)peerPickerController:(GKPeerPickerController *)picker
   didConnectPeer:(NSString *)peerID toSession:(GKSession *)session
{   
   // get the property names from person
   NSDictionary *personDictionary = [[person entity] propertiesByName];
   
   // create a new NSMutableDictionary to store the data
   NSMutableDictionary *dictionary = [[NSMutableDictionary alloc] init];
   
   // iterate through each property name in person
   for (NSString *key in [personDictionary allKeys])
      
      // add the property and its value in person to the dictionary
      [dictionary setValue:[person valueForKey:key] forKey:key];
   
   // archive dictionary
   NSData *data = [NSKeyedArchiver archivedDataWithRootObject:dictionary];
   
   // send the data to all connected peers
   [session sendDataToAllPeers:data withDataMode:GKSendDataReliable
      error:nil];
   [picker dismiss]; // dismiss the peer picker
   [picker release]; // release the picker GKPeerPickerController
} // end method peerPickerController:didConnectPeer:toSession:

// called when the user touches the cancel button of the peer picker
- (void)peerPickerControllerDidCancel:(GKPeerPickerController *)picker
{
   [picker dismiss]; // dismiss the peer picker
   [picker release]; // release the picker GKPeerPickerController
} // end method peerPickerControllerDidCancel:

// set the navigation item's title depending on person
- (void)updateTitle
{
   // set the title to the contact's name 
   [self.navigationItem setTitle:[person valueForKey:@"Name"]];
} // end method updateTitle

// called by the table view to find the number of rows in a given section
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:
   (NSInteger)section
{
   return [[person entity] properties].count; // return number of fields
} // end method tableView:numberOfRowsInSection:

// called by the table view to get a cell for the given index path
- (UITableViewCell *)tableView:(UITableView *)tableView
   cellForRowAtIndexPath:(NSIndexPath *)indexPath
{   
   static NSString *identifier = @"NormalCell";
   
   // get a reused cell
   UITableViewCell *cell =
      [tableView dequeueReusableCellWithIdentifier:identifier];
   
   // if there are no cells to be reused, create one
   if (cell == nil)
      cell = [[[UITableViewCell alloc] initWithFrame:CGRectZero
         reuseIdentifier:identifier] autorelease];
   
   // get the key at the appropriate index in the dictionary
   NSString *key = [[[[person entity] propertiesByName] allKeys]
      objectAtIndex:indexPath.row];
   NSString *value = [person valueForKey:key]; // get the value
   UILabel *label = [cell textLabel]; // get the label for the cell
   
   // update the text of the label
   label.text = [NSString stringWithFormat:@"%@: %@", key, value];
   return cell; // return the configured cell
} // end method tableView:cellForRowAtIndexPath:

// determines what orientations the view supports
- (BOOL)shouldAutorotateToInterfaceOrientation:
   (UIInterfaceOrientation)interfaceOrientation
{
   // we only support the portrait orientation
   return (interfaceOrientation == UIInterfaceOrientationPortrait);
} // end method shouldAutorotateToInterfaceOrientation:

// release this object's memory
- (void)dealloc
{
   [person release]; // release the person NSManagedObject
   [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
@end // end implementation ContactViewController


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

