// RootViewController.m
// RootViewController class implementation
#import "RootViewController.h"
#import "ContactViewController.h"

@implementation RootViewController

@synthesize fetchedResultsController, managedObjectContext;

// set up the View once it initializes
- (void)viewDidLoad
{
    [super viewDidLoad]; // call the superclass's viewDidLoad method

	// set up the edit and add buttons
   self.navigationItem.leftBarButtonItem = self.editButtonItem;
    
   // create the plus button
   UIBarButtonItem *addButton = [[UIBarButtonItem alloc]
      initWithBarButtonSystemItem:UIBarButtonSystemItemAdd target:self
      action:@selector(insertNewObject)];
   
   // add the plus button to the navigation bar's right side
   self.navigationItem.rightBarButtonItem = addButton;
   [addButton release]; // release the addButton UIBarButtonItem
	
   
	NSError *error; // create a new NSError
   
   // if fetchedResultsController failed to retrieve data
	if (![[self fetchedResultsController] performFetch:&error])
      NSLog(@"Could not load data: %@", [error description]);
   
   // initialize serverSession as a server
   serverSession = [[GKSession alloc] initWithSessionID:nil
      displayName:nil sessionMode:GKSessionModeServer];
   serverSession.delegate = self; // set the delegate to this object
   
   // this object will receive data from serverSession
   [serverSession setDataReceiveHandler:self withContext:NULL];
   serverSession.available = YES; // begin accepting connections
} // end method viewDidLoad

// called when the GKSession receives a connection request
- (void)session:(GKSession *)session didReceiveConnectionRequestFromPeer:
   (NSString *)peerID
{
   connectingPeerID = peerID; // save peerID
   
   // get the display name for the connecting peer
   NSString *name = [session displayNameForPeer:connectingPeerID];
   
   // display an alert prompting the user if the peer can connect
   NSString *message =
      [NSString stringWithFormat:@"%@ wishes to connect", name];
      
   // create the UIAlertView   
   UIAlertView *connectionAlert = [[UIAlertView alloc] initWithTitle:
      @"Connection Request" message:message delegate:self
      cancelButtonTitle:@"Deny" otherButtonTitles:@"Allow", nil];
   [connectionAlert show]; // show the alert
} // end method session:didRecieveConnectionRequestFromPeer:

// called when the user touches a button of the alert view
- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:
   (NSInteger)buttonIndex
{
   // accept the connection request
   [serverSession acceptConnectionFromPeer:connectingPeerID error:nil];
} // end method alertView:clickedButtonAtIndex:

// called when the user touches the cancel button of the alert view
- (void)alertViewCancel:(UIAlertView *)alertView
{
   // deny the connection request
   [serverSession denyConnectionFromPeer:connectingPeerID];
} // end method alertViewCancel:

// called when we receive data from a connected peer
- (void)receiveData:(NSData *)data fromPeer:(NSString *)peer inSession:
   (GKSession *)session context:(void *)context
{
   // extract the NSDictionary from the received data
   NSDictionary *dictionary =
      [NSKeyedUnarchiver unarchiveObjectWithData:data];
   
   // get the managed object context from the fetched results controller
   NSManagedObjectContext *objectContext =
      [fetchedResultsController managedObjectContext];
   
   // get the entity description from the fetched results controller
	NSEntityDescription *entity =
      [[fetchedResultsController fetchRequest] entity];
   
   // insert a new object into objectContext with the given name
	NSManagedObject *newManagedObject =
      [NSEntityDescription insertNewObjectForEntityForName:entity.name
      inManagedObjectContext:objectContext];
   
   // loop through all the keys in the received dictionary
   for (NSString *key in [dictionary allKeys])
      
      // update the values in the new managed object we're inserting
      [newManagedObject setValue:[dictionary valueForKey:key] forKey:key];
   
   NSError *error; // declare an NSError for the save operation
   
   // if the context doesn't save properly
   if (![objectContext save:&error])
   {
      // log the error
      NSLog(@"Error saving context: %@", [error description]);
   } // end if
   else
   {
      // insert a new row in the table view for the new object
      [self.tableView insertRowsAtIndexPaths:[NSArray arrayWithObject:
         [NSIndexPath indexPathForRow:0 inSection:0]] withRowAnimation:
         UITableViewRowAnimationLeft];
      [self.tableView reloadData]; // refresh the table view
   } // end else
} // end method recieveData:fromPeer:inSession:context:

// called when the user touches the plus button
- (void)insertNewObject
{
   // create new AddViewController
   AddViewController *controller = [[AddViewController alloc] init];
   controller.delegate = self; // set controller’s delegate to self
   
   // show the new controller
   [self presentModalViewController:controller animated:YES];
} // end method insertNewObject

// called when the user touches the Done button in the AddViewController
- (void)addViewControllerDidFinishAdding:(AddViewController *)controller
{
   // get the managed object context from the fetched results controller
   NSManagedObjectContext *objectContext =
   [fetchedResultsController managedObjectContext];
   
   // get the entity description from the fetched results controller
	NSEntityDescription *entity =
   [[fetchedResultsController fetchRequest] entity];
   
   // insert a new object into objectContext with the given name
	NSManagedObject *newManagedObject =
      [NSEntityDescription insertNewObjectForEntityForName:entity.name
      inManagedObjectContext:objectContext];
	
   NSDictionary *values = [controller values]; // get the entered data

   // loop through the field names in the entered data
   for (NSString *key in values)
      
      // add the contact's information to the object under the key
      [newManagedObject setValue:[values valueForKey:key] forKey:key];
	
   NSError *error; // declare an NSError for the save operation
   
   // if the context doesn't save properly
   if (![objectContext save:&error])
      NSLog(@"Error saving context: %@", [error description]);

   // dismiss the AddViewController
   [self dismissModalViewControllerAnimated:YES];
   [self.tableView reloadData]; // refresh the table view's data
} // end method addViewControllerDidFinishAdding:

// called by the table view to find the number of secitons it has
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
   // get the number of sections from the fetched results controller
   NSUInteger count = [[fetchedResultsController sections] count];
   
   // if the fetched results controller reports 0 sections
   if (count == 0)
      count = 1; // change count to 1
   
   return count; // return the number of sections
} // end method numberOfSectionsInTableView:

// called by the UITableView to get a cell for the given index path
- (NSInteger)tableView:(UITableView *)tableView
   numberOfRowsInSection:(NSInteger)section
{
   // get all the sections in the fetched results controller
   NSArray *sections = [fetchedResultsController sections];
   NSUInteger count = 0; // initialize count to 0
   
   // if sections contains at least one object
   if ([sections count])
   {
      // get the object at the given index
      id <NSFetchedResultsSectionInfo> sectionInfo =
         [sections objectAtIndex:section];
      
      // get the number of rows in the section
      count = [sectionInfo numberOfObjects];
   } // end if
   
   return count; // return the number of rows in the section
} // end method tableView:numberOfRowsInSection:

// called by the table view to get a cell for the given index path
- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
   static NSString *CellIdentifier = @"Cell"; // normal cell identifier
   
   // get a reused cell
   UITableViewCell *cell =
      [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
   
   // if no reusable cells are available
   if (cell == nil)
      
      // create a new cell
      cell = [[[UITableViewCell alloc]
         initWithStyle:UITableViewCellStyleDefault
         reuseIdentifier:CellIdentifier] autorelease];
   
      // get the managed object for the given index path
	NSManagedObject *managedObject = 
      [fetchedResultsController objectAtIndexPath:indexPath];
   
   // update the text in the cell with the contact's name
	cell.textLabel.text =
      [[managedObject valueForKey:@"Name"] description];	
   
   // make the cell display an arrow on the right side
   cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
   return cell; // return the configured cell
} // end method tableView:cellForRowAtIndexPath:

// called when the user touches one of the rows in the table view
- (void)tableView:(UITableView *)tableView
   didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
   // create a new ContactViewController
   ContactViewController *controller = [[ContactViewController alloc]
      initWithNibName:@"ContactViewController" bundle:nil];
   
   // get the managed object at the given index path
   NSManagedObject *selectedObject =
      [[self fetchedResultsController] objectAtIndexPath:indexPath];
   
   // set the ContactViewController's person to be the managed object
   controller.person = selectedObject;
   [controller updateTitle]; // update the title in controller
   
   // show the ContactViewController
   [self.navigationController pushViewController:controller animated:YES];
   [controller release]; // release the controller ContactViewContorller
} // end method tableView:didSelectRowAtIndexPath:

// called when the user edits a cell in the table view
- (void)tableView:(UITableView *)tableView
   commitEditingStyle:(UITableViewCellEditingStyle)editingStyle
   forRowAtIndexPath:(NSIndexPath *)indexPath
{
   // if the user deleted a cell
   if (editingStyle == UITableViewCellEditingStyleDelete)
   {
      // get the managed object context
		NSManagedObjectContext *context =
         [fetchedResultsController managedObjectContext];
      
      // delete the managed object in the context at the given index path
		[context deleteObject:
         [fetchedResultsController objectAtIndexPath:indexPath]];
		
		NSError *error; // declare an NSError for the save operation
      
      // if the context fails to save
		if (![context save:&error])
         NSLog(@"Error saving context: %@", [error description]);
		
      // delete the row from the table view
		[tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:
         indexPath] withRowAnimation:UITableViewRowAnimationFade];
   } // end if
} // end method tableView:commitEditingStyle:forRowAtIndexPath:

// called by the table view to determine if a given row is re-orderable
- (BOOL)tableView:(UITableView *)tableView
   canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    return NO; // none of the cells in this table can be moved
} // end method tableView:canMoveRowAtIndexPath:

// returns the fetched results controller that controls this table
- (NSFetchedResultsController *)fetchedResultsController
{
   // if a fetched results controller has already been initialized
   if (fetchedResultsController != nil)
      return fetchedResultsController; // return the controller
   
	// create the fetch request for the entity
	NSFetchRequest *fetchRequest = [[NSFetchRequest alloc] init];
	
   // edit the entity name as appropriate.
	NSEntityDescription *entity = [NSEntityDescription entityForName:
      @"Person" inManagedObjectContext:managedObjectContext];
	[fetchRequest setEntity:entity];
	
	// edit the sort key as appropriate.
	NSSortDescriptor *sortDescriptor =
      [[NSSortDescriptor alloc] initWithKey:@"Name" ascending:YES];
	NSArray *sortDescriptors =
      [[NSArray alloc] initWithObjects:sortDescriptor, nil];
	
	[fetchRequest setSortDescriptors:sortDescriptors];
	
	// edit the section name key path and cache name if appropriate
   // nil for section name key path means "no sections"
	NSFetchedResultsController *aFetchedResultsController =
      [[NSFetchedResultsController alloc] initWithFetchRequest:
      fetchRequest managedObjectContext:managedObjectContext
      sectionNameKeyPath:nil cacheName:@"Root"];
   
   aFetchedResultsController.delegate = self;
	self.fetchedResultsController = aFetchedResultsController;
	
	[aFetchedResultsController release]; // release temporary controller
	[fetchRequest release]; // release fetchRequest NSFetcheRequest
	[sortDescriptor release]; // release sortDescriptor NSSortDescriptor
	[sortDescriptors release]; // release sortDescriptor NSArray
	
	return fetchedResultsController;
}    

// releases this object's memory
- (void)dealloc
{
   [fetchedResultsController release]; // release fetchedResultsController
   [managedObjectContext release]; // release managedObjectContext
   [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
@end // end class RootViewController


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

