// Slideshow.h
// Interface for class which represents a slideshow.
#import <Foundation/Foundation.h>
#import <MediaPlayer/MediaPlayer.h>
#import "MediaItem.h"

// the transition effect in the slideshow
typedef enum _transitionEffects
{
   TransitionEffectFade = 0, // fade from one slide to the next
   TransitionEffectSlide = 1, // move next slide in from the right
   TransitionEffectFlip = 2, // flip from one slide to the next
} TransitionEffect;

// Slideshow interface
@interface Slideshow : NSObject <NSCoding>
{
   NSMutableArray *media; // the slides in the slideshow
   MPMediaItemCollection *music; // the music for the slideshow
   TransitionEffect effect; // the effect to transition between slides
   NSString *title; // the slideshow's title
} // end instance variable declaration

// declare music, effect, media and title as properties
@property (nonatomic, retain) MPMediaItemCollection *music;
@property TransitionEffect effect;
@property (nonatomic, retain) NSMutableArray *media;
@property (nonatomic, retain) NSString *title;

- (UIImage *)firstImage; // returns the first image in the slideshow
@end // end interface Slideshow

// NSCoding category
@interface UIImage (NSCoding) // add NSCoding protocol methods to UIImage
- (id)initWithCoder:(NSCoder *)decoder; // create slideshow from archive
- (void)encodeWithCoder:(NSCoder *)encoder; // archive slideshow
@end // end Slideshow class


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

