// Slideshow.m
// Represents a slideshow.
#import "Slideshow.h"

@implementation Slideshow

@synthesize media; // generate get and set methods for media
@synthesize music; // generate get and set methods for music
@synthesize effect; // generate get and set methods for effect
@synthesize title; // generate get and set methods for title

// initialize this object
- (id)init
{
   // if the superclass initializes properly
   if (self = [super init])
      media = [[NSMutableArray alloc] init]; // initialize media
   
   return self; // return this object
} // end method init

// initialize this object from the given NSCoder
- (id)initWithCoder:(NSCoder *)decoder
{
   // if the superclass initializes properly
   if (self = [super init])
   {
      // decode media from the NSCoder
      self.media = [decoder decodeObjectForKey:@"media"];
      
      // decode effect from the NSCoder
      self.effect = [decoder decodeIntForKey:@"effect"];
      
      // decode music from the NSCoder
      self.music = [decoder decodeObjectForKey:@"music"];
      
      // decode title from the NSCoder
      self.title = [decoder decodeObjectForKey:@"title"];
   } // end if
   
   return self; // return this object
} // initWithCoder:

// encode this object into the given NSCoder
- (void)encodeWithCoder:(NSCoder *)coder                      
{                                                             
   [coder encodeObject:media forKey:@"media"]; // encode media
   [coder encodeInt:effect forKey:@"effect"]; // encode effect
   [coder encodeObject:music forKey:@"music"]; // encode music
   [coder encodeObject:title forKey:@"title"]; // encode title
} // end method encodeWithCoder:                              

// returns the first image in this slideshow
- (UIImage *)firstImage
{
   UIImage *firstImage = nil; // set first image to nil until we find one
   BOOL found = NO; // we’ve not found the first image yet
   
   // loop through each slide
   for (int i = 0; i < media.count && !found; i++)
   {
      MediaItem *item = [media objectAtIndex:i]; // get slide at index i
      
      // if the slide is an image
      if (item.type == MediaTypeImage)
      {
         firstImage = item.data; // assign item to firstImage
         found = YES; // we found the first image
      } // end if
   } // end for
   
   return firstImage; // return the first image
} // end method firstImage

// release this object's memory
- (void)dealloc
{
   [media release]; // release the media NSMutableArray
   [music release]; // release the music MPMediaItemCollection
   [title release]; // release the title NSString
   [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
@end // end Slideshow class

// NSCoding category for UIImage
@implementation UIImage (NSCoding) 

// initialize the UIImage with the given NSCoder
- (id)initWithCoder:(NSCoder *)decoder
{
   // if the superclass initializes properly
   if (self = [super init])
   {
      // decode the NSData from the NSCoder
      NSData *data = [decoder decodeObjectForKey:@"UIImage"];
      self = [self initWithData:data]; // initialize the UIImage with data
   } // end if
   
   return self; // return this object
} // end method initWithCoder:

// encode the UIImage into the given NSCoder
- (void)encodeWithCoder:(NSCoder *)encoder
{
   // get the PNG representation of the UIImage
   NSData *data = UIImagePNGRepresentation(self);
   
   // encode the data using the NSCoder
   [encoder encodeObject:data forKey:@"UIImage"];
} // end method encodeWithCoder:
@end // end NSCoding category


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

