//  RootViewController.m
//  This class controls the main list of slideshows.
#import "RootViewController.h"

@implementation RootViewController

@synthesize slideshows; // generate get method for slideshows

// set up the main view
- (void)viewDidLoad
{
   [super viewDidLoad]; // call the superclass's viewDidLoad method
   
   // find this app's documents directory
   NSArray *paths = NSSearchPathForDirectoriesInDomains(
      NSDocumentDirectory, NSUserDomainMask, YES);
   
   // get the first directory
   NSString *directory = [paths objectAtIndex:0];
   
   // concatenate the file name "data.slideshows" to the end of the path
   NSString *filePath = [[NSString alloc] initWithString:
      [directory stringByAppendingPathComponent:@"data.slideshows"]];
   
   // unarchive slideshows from the file data.slideshows
   slideshows =
   [[NSKeyedUnarchiver unarchiveObjectWithFile:filePath] mutableCopy];
   [filePath release]; // release the filePath NSString
   
   // if no data was unarchived from data.slideshows
   if (slideshows == nil)
      slideshows = [[NSMutableArray alloc] init]; // create slideshows
   
   [self.navigationItem setTitle:@"Slideshows"]; // set the bar title
   
   // create the New Slideshow button for adding a new slideshow
   UIBarButtonItem *newSlideshowButton = [[UIBarButtonItem alloc]
      initWithTitle:@"New" style:UIBarButtonItemStylePlain target:self
      action:@selector(addSlideshow)];
   
   // create the back button for when the user navigates away
   UIBarButtonItem *backButton = [[UIBarButtonItem alloc]
      initWithTitle:@"Back" style:UIBarButtonItemStylePlain target:nil
      action:nil];
   
   // add the "New" Button to the right side of the navigation bar
   self.navigationItem.rightBarButtonItem = newSlideshowButton;
   
   // add the "Edit" Button to the left side of the navigation bar
   self.navigationItem.leftBarButtonItem = self.editButtonItem;
   
   // set the back button to be displayed when the user navigates away
   [self.navigationItem setBackBarButtonItem:backButton];
   [newSlideshowButton release]; // release the newSlideshowButton
   [backButton release]; // release the backButton
} // end method viewDidLoad

// called when the view is about to be displayed
- (void)viewWillAppear:(BOOL)animated
{
   [super viewWillAppear:animated]; // pass message to the superclass
   
   // set the navigation bar to be not hidden
   [self.navigationController setNavigationBarHidden:NO animated:NO];
   [(UITableView *)self.view reloadData]; // update the table
} // end method viewWillAppear:

// method called when the plus button is touched
- (void)addSlideshow
{
   // create a new NameViewController
   NameViewController *controller = [[NameViewController alloc]
      initWithNibName:@"NameViewController" bundle:nil];
   controller.delegate = self; // set the delegate to this object
   
   // show the NameViewController
   [self presentModalViewController:controller animated:YES];
} // end method addSlideshow

// called when the user picks a name using the NameViewController
- (void)nameViewController:(NameViewController *)controller
                didGetName:(NSString *)name
{
   // hide the NameViewContorller
   [self dismissModalViewControllerAnimated:YES];
   
   // create a new Slideshow                         
   Slideshow *slideshow = [[Slideshow alloc] init];  
   slideshow.title = name; // update slideshow's name
   
   // create a new SlideshowDataViewController with the Slideshow       
   SlideshowDataViewController *dataController =                        
   [[SlideshowDataViewController alloc] initWithSlideshow:slideshow];
   [slideshows addObject:slideshow]; // add to the list of slideshows   
   
   // show the slideshow creator
   [self.navigationController pushViewController:dataController
      animated:YES];
   [slideshow release]; // release the Slideshow
   [dataController release]; // release the SlideshowDataViewController
} // end method nameViewController:didGetName:

// called when the user touched the edit button of a SlideshowCell
- (void)slideshowCellDidSelectEditButton:(SlideshowCell *)cell
{
   // get the index path for the touched cell
   NSIndexPath *indexPath = [self.tableView indexPathForCell:cell];
   
   // create a new SlideshowDataViewController with the touched slideshow
   SlideshowDataViewController *controller =
      [[SlideshowDataViewController alloc] initWithSlideshow:
      [slideshows objectAtIndex:indexPath.row]];
   
   // show the SlideshowDataViewController
   [self.navigationController pushViewController:controller
      animated:YES];
} // end method slideshowCellDidSelectEditButton:

// called when the user touched the play button of a SlideshowCell
- (void)slideshowCellDidSelectPlayButton:(SlideshowCell *)cell
{
   // find the index path where the given cell is located
   NSIndexPath *indexPath = [self.tableView indexPathForCell:cell];
   
   // create a new SlideshowViewController                   
   SlideshowViewController *controller =                     
   [[SlideshowDataViewController alloc] initWithSlideshow:
      [slideshows objectAtIndex:indexPath.row]];             
   
   // show the SlideshowDataViewController
   [self.navigationController pushViewController:controller
                                        animated:YES];
} // end method slideshowCellDidSelectPlayButton:

// called by the table view to determine the number of sections it has
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
   return 1; // the number of sections in the table view
} // end method numberOfSectionsInTableView:


// called by the table view to get the number of rows in a given section
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:
(NSInteger)section
{
   return slideshows.count; // return the number of slideshows
} // end method tableView:numberOfRowsInSection:

// called by the table view to get the cells it needs to populate itself
- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
   static NSString *CellIdentifier = @"SlideshowCell";
   
   // get a reusable cell
   SlideshowCell *cell = (SlideshowCell *)[tableView
      dequeueReusableCellWithIdentifier:CellIdentifier];
   
   // if no reusable cells are available, create one
   if (cell == nil)
   {
      cell = [[[SlideshowCell alloc] initWithStyle:
         UITableViewCellStyleDefault reuseIdentifier:CellIdentifier]
         autorelease];
   } // end if
   
   cell.delegate = self; // set cell’s delegate to this controller
   
   // make the cell do nothing when selected
   cell.selectionStyle = UITableViewCellSelectionStyleNone;
   
   // get the Slideshow for the given row                          
   Slideshow *slideshow = [slideshows objectAtIndex:indexPath.row];
   
   // get the first image in the Slideshow at the correct index
   UIImage *image = [slideshow firstImage];                    
   cell.thumbnail.image = image; // set the cell's thumbnail image
   cell.title.text = slideshow.title; // set the cell’s title
   
   return cell; // return the configured cell to the table view
} // end method tableView:cellForRowAtIndexPath:

// called by the table view to determine the height of its rows
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:
   (NSIndexPath *)indexPath
{
   return rowHeight; // all rows are the same height
} // end method tableView:heightForRowAtIndexPath:

// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:
(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:
(NSIndexPath *)indexPath
{   
   if (editingStyle == UITableViewCellEditingStyleDelete)
   {
      [slideshows removeObjectAtIndex:indexPath.row];
      // Delete the row from the data source.
      [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:
         indexPath] withRowAnimation:UITableViewRowAnimationFade];
   } // end if
} // end method tableView:commitEditingStyle:forRowAtIndexPath:

// release this RootViewController's memory
- (void)dealloc
{
   [slideshows release]; // release the slideshows NSMutableArray
   [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
@end

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

