// SlideshowViewController.h
// Controller for a view that shows a slideshow.
// Implementation in SlideshowViewController.m
#import <UIKit/UIKit.h>
#import <MediaPlayer/MediaPlayer.h>
#import "Slideshow.h"

@interface SlideshowViewController : UIViewController
{
   Slideshow *slideshow; // the Slideshow that’s being played
   MPMusicPlayerController *musicPlayer; // plays the slideshow's music
   MPMoviePlayerController *moviePlayer; // plays the slideshow's video
   UIImageView *currentImageView; // the current image being displayed
   int pictureIndex; // the index of the current place in Slideshow
} // end instance variable declaration

// declare slideshow as a property
@property (nonatomic, retain) Slideshow *slideshow;

// returns an image view for the given MediaItem
- (UIImageView *)nextImageViewWithMedia:(MediaItem *)item;

// transitions the slideshow to a new image
- (void)displayNewImage:(MediaItem *)item;

// transitions the slideshow to a new video
- (void)displayNewVideo:(MediaItem *)item;
- (void)videoFinished:(NSNotification *)n; // called when video finishes
- (void)exitShow; // ends the slideshow and returns to the previous view
- (void)changeSlide; // moves to the next slide in the slideshow

// called when the transition between two slides finishes
- (void)transitionFinished:(NSString *)animationId finished:(BOOL)finished
                   context:(void *)context;                                               
@end // end SlideshowViewController interface

// additional method for UIImageView
@interface UIImageView (Scaling)

// scales the image view to fill the given bounds
- (void)expandToFill:(CGRect)bounds;
@end // end category Scaling of interface UIImageView


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

