//  Controller.h
//  Controller class for the Favorite Twitter Searches app.
#import <UIKit/UIKit.h>

// constants that control the height of the buttons and the spacing
#define BUTTON_SPACING 10
#define BUTTON_HEIGHT 40

@interface Controller : NSObject // this line is autogenerated
{
   // Interface Builder outlets
   IBOutlet UIScrollView *scrollView; // for scrollable favorites
   IBOutlet UITextField *tagField; // text field for entering tag
   IBOutlet UITextField *queryField; // text field for entering query
   
   // stores the tag names and searches
   NSMutableDictionary *tags;
   
   // stores the Buttons representing the searches
   NSMutableArray *buttons;
   
   // stores the info buttons for editing existing searches
   NSMutableArray *infoButtons;
   
   // location of the file in which favorites are stored
   NSString *filePath;
} // end instance variable declarations

- (IBAction)addTag:sender; // adds a new tag
- (IBAction)clearTags:sender; // clears all of the tags
- (void)addNewButtonWithTitle:(NSString *)title; // creates a new button
- (void)refreshList; // refreshes the list of buttons
- (void)buttonTouched:sender; // handles favorite button event
- (void)infoButtonTouched:sender; // handles info button event
@end // end Controller interface

// begin UIButton's sorting category
@interface UIButton (sorting)
   // compares this UIButton's title to the given UIButton's title
   - (NSComparisonResult)compareButtonTitles:(UIButton *)button;
@end // end catagory sorting of interface UIButton

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

