//  FlipsideViewController.m
//  Controller for the flipside of the Flag Quiz app
#import "FlipsideViewController.h"
#import "MainViewController.h"

@implementation FlipsideViewController

// generate get and set methods for our properties
@synthesize delegate;
@synthesize choicesControl;
@synthesize africaSwitch;
@synthesize asiaSwitch;
@synthesize europeSwitch;
@synthesize northAmericaSwitch;
@synthesize oceaniaSwitch;
@synthesize southAmericaSwitch;

// called when the main view finishes initializing
- (void)viewDidLoad
{
   // set the background color to the standard background color
   self.view.backgroundColor = [UIColor viewFlipsideBackgroundColor];
} // end method viewDidLoad

// called when the user touches the "Done" button
- (IBAction)done
{
   // if none of the switches are selected
   if (!africaSwitch.on && !asiaSwitch.on && !europeSwitch.on &&
      !oceaniaSwitch.on && ! northAmericaSwitch.on &&
      !southAmericaSwitch.on)
   {
      // show an alert prompting the user to select at least one region
      UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Error"
         message:@"Please select at least one region" delegate:self
         cancelButtonTitle:@"Ok" otherButtonTitles:nil];
      [alert show]; // show the alert
      [alert release]; // release the alert UIAlertView
   } // end if
   else
   {
      // get the selected index of choicesControl
      int index = [choicesControl selectedSegmentIndex];
      
      // update the number of guess rows on the frontside
      [(MainViewController *)self.delegate setGuessRows:index + 1];
      
      // update the enabled regions on the fronside with the switch values
      NSMutableDictionary *regions =
         [(MainViewController *)self.delegate regions];
      [regions setValue:[NSNumber numberWithBool:africaSwitch.on]
                 forKey:@"Africa"];
      [regions setValue:[NSNumber numberWithBool:asiaSwitch.on]
                 forKey:@"Asia"];
      [regions setValue:[NSNumber numberWithBool:europeSwitch.on]
                 forKey:@"Europe"];
      [regions setValue:[NSNumber numberWithBool:
         northAmericaSwitch.on] forKey:@"North_America"];
      [regions setValue:[NSNumber numberWithBool:oceaniaSwitch.on]
                 forKey:@"Oceania"];
      [regions setValue:[NSNumber numberWithBool:
         southAmericaSwitch.on] forKey:@"South_America"];
      
      // create a new quiz on the frontside
      [(MainViewController *)self.delegate resetQuiz];
      
      // flip back to the frontside
      [self.delegate flipsideViewControllerDidFinish:self]; 
   } // end else
} // end method done

// update the switches with values from the frontside
- (void)setSwitches:(NSDictionary *)dictionary
{
   // update each switch with its corresponding entry in the dictionary
   [africaSwitch setOn:[[dictionary valueForKey:@"Africa"] boolValue]];
   [asiaSwitch setOn:[[dictionary valueForKey:@"Asia"] boolValue]];
   [europeSwitch setOn:[[dictionary valueForKey:@"Europe"] boolValue]];
   [northAmericaSwitch setOn:
      [[dictionary valueForKey:@"North_America"] boolValue]];
   [oceaniaSwitch setOn:[[dictionary valueForKey:@"Oceania"] boolValue]];
   [southAmericaSwitch setOn:
      [[dictionary valueForKey:@"South_America"] boolValue]];
} // end method setSwitches:

// update choicesControl with the value from the frontside
- (void)setSelectedIndex:(int)index
{
   choicesControl.selectedSegmentIndex = index;
} // end method setSelectedIndex:

// free FlipsideViewController's memory
- (void)dealloc
{
   [choicesControl release]; // release choicesControl UISegmentedControl
   [africaSwitch release]; // release africaSwitch UISwitch
   [asiaSwitch release]; // release asiaSwitch UISwitch
   [europeSwitch release]; // release europeSwitch UISwitch
   [northAmericaSwitch release]; // release northAmericaSwitch UISwitch
   [oceaniaSwitch release]; // release oceaniaSwitch UISwitch
   [southAmericaSwitch release]; // release southAmericaSwitch UISwitch
   [super dealloc]; // call the superclass's dealloc method
}// end dealloc method
@end // end FlipsideViewController class


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

