//  MainViewController.h
//  Controller for the front side of the Flag Quiz app.
//  Implementation in MainViewController.m
#import "FlipsideViewController.h"

@interface MainViewController : UIViewController
   <FlipsideViewControllerDelegate>
{
   IBOutlet UIImageView *flagView; // displays the flag image
   IBOutlet UILabel *answerLabel; // displays if guess is correct
   IBOutlet UILabel *numCorrectLabel; // displays quiz's progress
   NSMutableArray *bars; // stores Segmented Controls
   NSMutableArray *filenames; // list of flag image file names
   NSMutableArray *quizCountries; // names of 10 countries in the quiz
   NSMutableDictionary *regions; // stores whether each region is enabled
   NSString *correctAnswer; // the correct country for the current flag
   int totalGuesses; // number of guesses made
   int numCorrect; // number of correct guesses
   int guessRows; // number of Segmented Controls displaying choices
} // end instance variable declarations

// declare the three outlets as properties
@property (nonatomic, retain) IBOutlet UIImageView *flagView;
@property (nonatomic, retain) IBOutlet UILabel *answerLabel;
@property (nonatomic, retain) IBOutlet UILabel *numCorrectLabel;

// method declarations
- (IBAction)showInfo; // displays the FlipsideView
- (IBAction)submitGuess:sender; // processes a guess
- (void)loadNextFlag; // displays a new flag and country choices
- (void)setGuessRows:(int)rows; // sets the number of Segmented Controls
- (void)resetQuiz; // starts a new quiz
- (NSMutableDictionary *)regions; // returns the regions dictionary
@end // end interface MainViewController;

@interface NSString (displayName) // begin NSString's displayName category
- (NSString *)convertToDisplayName; // converts file name to country name
@end // end category displayName of interface NSString

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

