//  FlipsideViewController.h
//  Controller for the flipside of the Painter app.
//  Implementation in FlipsideViewController.m
@protocol FlipsideViewControllerDelegate; // declare a new protocol

@interface FlipsideViewController : UIViewController
{
   id <FlipsideViewControllerDelegate> delegate; // this class's delegate
   IBOutlet UISlider *redSlider; // slider for changing amount of red
   IBOutlet UISlider *greenSlider; // slider for changing amount of green
   IBOutlet UISlider *blueSlider; // slider for changing amount of blue
   IBOutlet UISlider *widthSlider; // slider for chaning line width
   IBOutlet UIView *colorView; // view that displays the current color
   BOOL clearScreen; // was the Clear Screen button touched?
} // end instance variable declaration

// declare delegate and outlets as properties
@property(nonatomic, assign) id <FlipsideViewControllerDelegate> delegate;
@property(nonatomic, retain) IBOutlet UISlider *redSlider;
@property(nonatomic, retain) IBOutlet UISlider *greenSlider;
@property(nonatomic, retain) IBOutlet UISlider *blueSlider;
@property(nonatomic, retain) IBOutlet UISlider *widthSlider;
@property(nonatomic, retain) IBOutlet UIView *colorView;

- (IBAction)done; // called when the Done button is touched
- (IBAction)updateColor:sender; // called when a color slider is moved
- (IBAction)erase:sender; // called when the Erase button is touched
- (IBAction)clearScreen:sender; // called by the Clear Screen button

// sets the color and line width
- (void)setColor:(UIColor *)c lineWidth:(float)width;
@end // end interface FlipsideViewController

// protocol that the delegate implements
@protocol FlipsideViewControllerDelegate
- (void)flipsideViewControllerDidFinish:
   (FlipsideViewController *)controller; // return to the MainView
- (void)setColor:(UIColor *)color; // sets the current drawing color 
- (void)setLineWidth:(float)width; // sets the current drawing line width
- (void)resetView; // erases the entire painting
@end // end protocol FlipsideViewControllerDelegate


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

