// FlipsideViewController.m
// Controller for the flipside of the Painter app.
#import "FlipsideViewController.h"
#import "MainViewController.h"

@implementation FlipsideViewController

@synthesize delegate; // generate getter and setter for delegate
@synthesize redSlider; // generate getter and setter for redSlider
@synthesize greenSlider; // generate getter and setter for greenSlider
@synthesize blueSlider; // generate getter and setter for blueSlider
@synthesize widthSlider; // generate getter and setter for widthSlider
@synthesize colorView; // generate getter and setter for colorView

// called when view finishes loading
- (void)viewDidLoad
{
   // initialize the background color to the default
   self.view.backgroundColor = [UIColor viewFlipsideBackgroundColor];   
} // end method viewDidLoad

// called when view is going to be displayed
- (void)viewWillAppear:(BOOL)animated
{
   [super viewWillAppear:animated];
   clearScreen = NO; // reset clearScreen
} // end method viewWillAppear:

// set the values for color and lineWidth
- (void)setColor:(UIColor *)c lineWidth:(float)width
{
   // split the passed color into its RGB components
   const float *colors = CGColorGetComponents(c.CGColor);
   
   // update the sliders with the new value
   redSlider.value = colors[0]; // set the red slider’s value
   greenSlider.value = colors[1]; // set the green slider’s value
   blueSlider.value = colors[2]; // set the blue slider’s value
   
   // update the color of colorView to reflect the sliders
   colorView.backgroundColor = c;
   
   // update the width slider
   widthSlider.value = width;
} // end method setcolor:lineWidth:

// called when any of the color sliders are changed
- (IBAction)updateColor:sender
{
   // get the color from the sliders
   UIColor *color = [UIColor colorWithRed:redSlider.value
      green:greenSlider.value blue:blueSlider.value alpha:1.0];
   
   // update colorView to reflect the new slider values
   [colorView setBackgroundColor:color];
} // end method updateColor:

// called when the Eraser button is touched
- (IBAction)erase:sender
{
   // do all the changes in an animation block so all the sliders finish
   // moving at the same time
   [UIView beginAnimations:nil context:nil]; // begin animation block
   [UIView setAnimationDuration:0.5]; // set the animation length
   
   // set all sliders to their max value so the color is white
   [redSlider setValue:1.0]; // set the red slider’s value to 1
   [greenSlider setValue:1.0]; // set the green slider’s value to 1
   [blueSlider setValue:1.0]; // set the blue slider’s value to 1
   
   // update colorView to reflect the new slider values
   [colorView setBackgroundColor:[UIColor whiteColor]];
   [UIView commitAnimations]; // end animation block
} // end method erase

// called when the Clear Screen button is touched
- (IBAction)clearScreen:sender
{
   clearScreen = YES; // set clearScreen to YES
} // end method clearScreen:

// called when the Done button is touched
- (IBAction)done
{
   // set the new values for color and line width
   [self.delegate setColor:colorView.backgroundColor];
   [self.delegate setLineWidth:widthSlider.value];
   
   // if the user touched the Clear Screen button
   if (clearScreen)
      [self.delegate resetView]; // clear the canvas
   
   // flip the view back to the front side
   [self.delegate flipsideViewControllerDidFinish:self];   
} // end method done 

// free FlipsideViewController's memory
- (void)dealloc
{
  [redSlider release]; // release the redSlider UISlider
  [greenSlider release]; // release the greenSlider UISlider
  [blueSlider release]; // release the blueSlider UISlider
  [widthSlider release]; // release the widthSlider UISlider
  [colorView release]; // release the colorView UIView
  [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
  
@end

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

