//  MainViewController.m
//  Controller for the front side of the Painter app.
#import "MainViewController.h"
#import "MainView.h"

@implementation MainViewController

// make the main view the first responder
- (void)viewDidAppear:(BOOL)animated
{
   [super viewDidAppear:animated]; // pass message to superclass
   [self.view becomeFirstResponder]; // make main view the first responder
} // end method viewDidAppear

// resign the main view as the first responder
- (void)viewDidDisappear:(BOOL)animated
{
   [super viewDidDisappear:animated]; // pass message to superclass
   [self.view resignFirstResponder]; // resign view as first responder
} // end method viewDidDisappear:

// called when the Done button on the flipside is touched
- (void)flipsideViewControllerDidFinish:(FlipsideViewController *)c
{
   // make the app flip back to the main view
   [self dismissModalViewControllerAnimated:YES];
} // end method flipsideViewControllerDidFinish:

// called when the info button is touched
- (IBAction)showInfo
{       
   // load a new FlipsideViewController from FlipsideView.xib
   FlipsideViewController *controller = [[FlipsideViewController alloc]
      initWithNibName:@"FlipsideView" bundle:nil];
   
   controller.delegate = self; // set the delegate of controller
   
   // set the animation effect and show the flipside
   controller.modalTransitionStyle = UIModalTransitionStyleFlipHorizontal;
   [self presentModalViewController:controller animated:YES];
   
   // set the sliders on the flipside to the current values in view
   MainView *view = (MainView *)self.view; 
   [controller setColor:view.color lineWidth:view.lineWidth];
   [controller release]; // we are done with controller so release it
} // end method showInfo

// set the color of view
- (void)setColor:(UIColor *)color
{
   MainView *view = (MainView *)self.view; // get main view as a MainView
   view.color = color; // update the color in the main view
} // end method setColor:

// set the line width of view
- (void)setLineWidth:(float)width
{
   // set the line width of the main view
   MainView *view = (MainView *)self.view; // get main view as a MainView
   view.lineWidth = width; // update the line width in the main view
} // end method setLineWidth:

// clear the paintings in the main view
- (void)resetView
{
   MainView *view = (MainView *)self.view; // get main view as a MainView
   [view resetView]; // reset the main view
} // end method resetView
@end

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

