// RootViewController.m
// This class controls the main list of slideshows.
#import "RootViewController.h"

@implementation RootViewController

// called after the view is initialized
- (void)viewDidLoad
{
   [super viewDidLoad]; // initialize the superclass
   slideshows = [[NSMutableArray alloc] init]; // initialize slideshows
   [self.navigationItem setTitle:@"Slideshows"]; // set the bar title
   
   // create the newSlideshowButton for adding a new slideshow
   UIBarButtonItem *newSlideshowButton = [[UIBarButtonItem alloc]
      initWithTitle:@"New" style:UIBarButtonItemStylePlain target:self
      action:@selector(addSlideshow)];
   
   // create the back button for when the user navigates away
   UIBarButtonItem *backButton = [[UIBarButtonItem alloc]
      initWithTitle:@"Back" style:UIBarButtonItemStylePlain target:nil
      action:nil];
   
   // add the newSlideshowButton to the right side of the navigation bar
   [self.navigationItem setRightBarButtonItem:newSlideshowButton];
   self.navigationItem.leftBarButtonItem = self.editButtonItem;
   
   // set the back button to be displayed when the user navigates away
   [self.navigationItem setBackBarButtonItem:backButton];
   self.tableView.rowHeight = ROW_HEIGHT; // set the table's row height
   [newSlideshowButton release]; // release the newSlideshowButton
   [backButton release]; // release the backButton
} // end method viewDidLoad

// called when the view is about to be displayed
- (void)viewWillAppear:(BOOL)animated
{
   [super viewWillAppear:animated]; // pass message to the superclass
   
   // show the navigation bar
   [self.navigationController setNavigationBarHidden:NO animated:YES];
   [(UITableView *)self.view reloadData]; // update the table
} // end method viewWillAppear:

// called when the "New" button is touched
- (void)addSlideshow
{
   // create a new NameViewController
   NameViewController *controller = [[NameViewController alloc]
      initWithNibName:@"NameViewController" bundle:nil];
   controller.delegate = self; // set delegate to self
   
   // display the NameViewController
   [self presentModalViewController:controller animated:YES];
} // end method addSlideshow

// gets slideshow name from the NameView then displays SlideshowDataView
- (void)nameViewController:(NameViewController *)controller
   didGetName:(NSString *)name
{
   // hide the NameView
   [self dismissModalViewControllerAnimated:YES];
   
   // create a new SlideshowDataViewController
   SlideshowDataViewController *slideshow =
      [[SlideshowDataViewController alloc] init];
   [slideshows addObject:slideshow]; // add it to the list of slideshows
   slideshow.title = name; // title the slideshow with the given name
   
   // show the create slideshow view
   [self.navigationController pushViewController:slideshow animated:YES];
   [slideshow release]; // release the SlideshowDataViewController
} // end method nameViewController:didGetName:

// called by the table view to get the number of rows in a given section
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:
   (NSInteger)section
{
   return slideshows.count; // return one row for each slideshow
} // end method tableView:numberOfRowsInSection:

// called by the table view to get the cells it needs to populate itself
- (UITableViewCell *)tableView:(UITableView *)tableView
   cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
   // create cell identifier
   static NSString *CellIdentifier = @"SlideshowCell";
   
   // get a reusable cell
   SlideshowCell *cell = (SlideshowCell *)[tableView
      dequeueReusableCellWithIdentifier:CellIdentifier];
   
   // if no reusable cells are available
   if (cell == nil)
   {
      // create a new cell
      cell = [[[SlideshowCell alloc] initWithStyle:
         UITableViewCellStyleDefault reuseIdentifier:CellIdentifier]
         autorelease];
   } // end if
   
   cell.delegate = self; // set this object as cell's delegate
   
   // make the cell do nothing when selected
   cell.selectionStyle = UITableViewCellSelectionStyleNone;
   
   // get the SlideshowDataViewController for the given row
   SlideshowDataViewController *controller =
      [slideshows objectAtIndex:indexPath.row];
   
   // get the first image in the slideshow at the correct index
   UIImage *image = [controller firstImage];
   cell.thumbnail.image = image; // set the cell's thumbnail image
   cell.title.text = controller.title; // set the cell's text
   
   return cell; // return the configured cell to the table view
} // end method tableView:cellForRowAtIndexPath:

// called when the user touches the modify button of a SlideshowCell
- (void)slideshowCellDidSelectEditButton:(SlideshowCell *)cell
{
   // get the index path for the touched cell
   NSIndexPath *indexPath = [self.tableView indexPathForCell:cell];
   [self.navigationController pushViewController:
      [slideshows objectAtIndex:indexPath.row] animated:YES];
} // end method slideshowCellDidSelectEditButton:

// called when the user touches the play button of a SlideshowCell
- (void)slideshowCellDidSelectPlayButton:(SlideshowCell *)cell
{
   // find the index path where the given cell is located
   NSIndexPath *indexPath = [self.tableView indexPathForCell:cell];
   
   // get the SlideshowDataViewController at the index path
   SlideshowDataViewController *data =
      [slideshows objectAtIndex:indexPath.row];
   
   // create a new SlideshowViewController
   SlideshowViewController *controller =
      [[SlideshowViewController alloc] init];
   controller.pictures = data.pictures; // set controller's pictures
   controller.effect = data.effect; // set controller's effect
   controller.music = data.music; // set controller's music
   
   // hide the navigation bar
   [self.navigationController setNavigationBarHidden:YES animated:YES];
   
   // show the slideshow
   [self.navigationController pushViewController:controller animated:YES];
} // end method slideshowCellDidSelectPlayButton:

// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:
   (UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:
   (NSIndexPath *)indexPath
{   
   // "delete" editing style is committed 
   if (editingStyle == UITableViewCellEditingStyleDelete)
   {
      // remove contact at indexPath.row
      [slideshows removeObjectAtIndex:indexPath.row];
      
      // delete the row from the table view
      [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject: 
         indexPath] withRowAnimation:UITableViewRowAnimationFade];
   } // end if
} // end method tableView:commitEditingStyle:forRowAtIndexPath:

// called when the user moves a row in the table
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:
   (NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
   // get the SlideshowDataViewController for the moved row
   SlideshowDataViewController *data =
      [[slideshows objectAtIndex:fromIndexPath.row] retain];
   
   // remove the moved SlideshowDataViewController
   [slideshows removeObjectAtIndex:fromIndexPath.row];
   
   // insert the SlideshowDataViewController in the new position
   [slideshows insertObject:data atIndex:toIndexPath.row];
   [data release]; // release the data SlideshowDataViewController
} // end method tableView:moveRowAtIndexPath:toIndexPath:

// called by the table view to check if a given row can be moved
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:
(NSIndexPath *)indexPath
{
   return YES; // all the rows in this table can be moved
} // end method tableView:canMoveRowAtIndexPath:

// release this object's memory
- (void)dealloc
{
   [slideshows release]; // release the slideshows NSMutableArray
   [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
@end // end implementation RootViewController


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

