// SlideshowDataViewController.h
// Manages the pictures, sounds and effects of a slideshow.
// Implementation in SlideshowDataViewController.m
#import <MediaPlayer/MediaPlayer.h>
#import "SlideshowViewController.h"

const static float ROW_HEIGHT = 100; // the height of the rows

// SlideshowDataViewController interface declaration
@interface SlideshowDataViewController : UITableViewController
   <UIImagePickerControllerDelegate, UINavigationControllerDelegate,
   MPMediaPickerControllerDelegate, UIActionSheetDelegate>
{   
   UIImagePickerController *imagePicker; // controller for picking images
   MPMediaPickerController *musicPicker; // controller for picking music 
   MPMediaItemCollection *music; // the chosen music for the slideshow   
   
   // View used to play the slideshow
   SlideshowViewController *slideshowViewController;
   UIActionSheet *effectSheet; // a sheet for choosing an effect
   UIToolbar *toolbar; // the toolbar at the bottom
   NSMutableArray *pictures; // the chosen pictures
   TransitionEffect effect; // the transition effect
   NSString *title; // this slideshow's title
   BOOL firstLoad; // is this the first load of this object?
   BOOL returnFromImagePicker; // are we returning from the image picker?
} // end instance variable declaration

// declare pictures, effect, music and title as properties
@property (nonatomic, readonly) NSMutableArray *pictures;
@property (nonatomic, readonly) TransitionEffect effect;
@property (nonatomic, readonly) MPMediaItemCollection *music;
@property (nonatomic, retain) NSString *title;

- (void)addPhoto; // adds a new photo to the slideshow
- (void)addMusic; // adds music to the slideshow
- (void)addEffect; // adds the effect for the slideshow
- (void)startSlideshow; // begins the slideshow
- (UIImage *)firstImage; // return the first image in the slideshow
@end // end interface SlideshowDataViewController

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

