// SlideshowViewController.h
// Controller for a View that shows a slideshow.
// Implementation in SlideshowViewController.m
#import <UIKit/UIKit.h>
#import <MediaPlayer/MediaPlayer.h>

typedef enum _transitionEffects
{
   TransitionEffectFade, // represents fade image transition effect
   TransitionEffectSlide // represents slide image transition effect
} TransitionEffect;

@interface SlideshowViewController : UIViewController
{
   NSMutableArray *pictures; // the pictures in this slideshow
   TransitionEffect effect; // the transition effect for the slideshow
   MPMediaItemCollection *music; // the music to play during the slideshow
   MPMusicPlayerController *musicPlayer; // plays the music               
   NSTimer *timer; // generates event to move to the next slide
   UIImageView *currentImageView; // the current image being displayed
   int pictureIndex; // the index in pictures of the current slide
} // end instance variable declaration

// declare pictures, effect and music as properties
@property (nonatomic, assign) NSMutableArray *pictures;
@property (nonatomic, assign) TransitionEffect effect;
@property (nonatomic, assign) MPMediaItemCollection *music;

- (UIImageView *)nextImageView; // returns the next image to display
- (void)exitShow; // returns the app to the previous screen
- (void)timerFired:(NSTimer *)timer; // progresses the slideshow
@end // end interface SlideshowViewController

// additional method for UIImageView
@interface UIImageView (Scaling)

// scales the image view to fill the given bounds
- (void)expandToFill:(CGRect)bounds;
@end // end category Scaling of interface UIImageView

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

