// SpotOnViewController.h
// SpotOnViewController interface declaration.
// Implementation in SpotOnViewController.m
#import <UIKit/UIKit.h>
#import <CoreGraphics/CGBase.h>
#import <QuartzCore/CoreAnimation.h>
#import <AVFoundation/AVFoundation.h>

@interface SpotOnViewController : UIViewController <UIAlertViewDelegate>
{
   IBOutlet UILabel *scoreLabel; // label for displaying the score
   IBOutlet UILabel *levelLabel; // label for displaying the level
   IBOutlet UILabel *highScoreLabel; // label for displaying high score
   NSMutableArray *spots; // stores the spot images
   NSMutableArray *lives; // stores the Views representing remaining lives
   AVAudioPlayer *hitPlayer; // plays a sound when a spot is touched
   AVAudioPlayer *missPlayer; // plays a sound when a spot is missed
   AVAudioPlayer *disappearPlayer; // plays a sound when a spot disappears
   int spotsTouched; // number of spots touched
   int score; // current score
   int level; // current level
   float drawTime; // how long each spot remains on the screen
   BOOL gameOver; // has the game ended?   
   UIImage *touchedImage; // touched spot image
   UIImage *untouchedImage; // untouched spot image
} // end instance variable declaration

// declare our outlets as properties
@property(nonatomic, retain) IBOutlet UILabel *scoreLabel;
@property(nonatomic, retain) IBOutlet UILabel *levelLabel;
@property(nonatomic, retain) IBOutlet UILabel *highScoreLabel;

- (void)resetGame; // starts a new game
- (void)addNewSpot; // adds a new spot to the game

// called when spots disappear
- (void)finishedAnimation:(NSString *)animationId finished:(BOOL)finished
   context:(void *)context;
- (void)touchedSpot:(UIImageView *)spot; // called when a spot is touched
@end // end interface SpotOnViewController

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

