// Controller.m
// Controller class for the tip calculator app.
#import "Controller.h"

@implementation Controller // begin implementation of Controller

// called after all the GUI elements have been loaded
- (void)awakeFromNib
{
   [billField becomeFirstResponder]; // display keyboard for billField
} // end method awakeFromNib

// called when the user touches a key or button
- (IBAction)calculateTip:(id)sender
{
   static BOOL toggle = YES; // was this method trigger by the user?
   
   // the user touched the keypad or moved the Slider
   if (toggle)
   {
      toggle = NO; // this method will next be called programmatically
      // retrieve the string in billField
      NSString *billFieldText = billField.text;
   
      // convert billFieldText to a float
      float newTotal = [billFieldText floatValue];
   
      // retrieve the slider value (between 0 and 0.3)
      float customTipPercent = customPercentSlider.value;
   
      // determine if billField generated the event
      if (sender == billField)
      {
         // delete key pressed        
         if (billFieldText.length < billTotal.length)
            billTotal = [NSString stringWithFormat:@"%.02f", 
               newTotal / 10];
         else // new digit entered
            billTotal = [NSString stringWithFormat:@"%.02f",
                newTotal * 10];
      
         // update billField with the properly formatted number
         billField.text = billTotal;
      
         // update newTotal with the new value
         newTotal = [billTotal floatValue];
      
         // calculate the tips for 10, 15 and 20%
         float tenTip = newTotal * 0.10;
         float fifteenTip = newTotal * 0.15;
         float twentyTip = newTotal * 0.20;
      
         // set the values for the "Tip" fields
         tipFieldTen.text = [NSString stringWithFormat:@"%.02f", tenTip];
         tipFieldFifteen.text =
            [NSString stringWithFormat:@"%.02f", fifteenTip];
         tipFieldTwenty.text =
            [NSString stringWithFormat:@"%.02f", twentyTip];
      
         // set the values for the "Total" fields 
         totalFieldTen.text =
            [NSString stringWithFormat:@"%.02f", newTotal + tenTip];
         totalFieldFifteen.text =
            [NSString stringWithFormat:@"%.02f", newTotal + fifteenTip];
         totalFieldTwenty.text =
            [NSString stringWithFormat:@"%.02f", newTotal + twentyTip];
      } // end if
      // determine if customPercentSlider generated the event
      else if (sender == customPercentSlider)
      {
         // the "Custom" slider was moved
         // round the value to a whole number
         int percentage = (int)(customTipPercent * 100);
      
         // update the label with the new percentage followed by %
         customPercentLabel.text =
            [NSString stringWithFormat:@"%i%%", percentage];
      
         // convert percentage back to float and assign to Slider's value
         float newSliderValue = ((float) percentage) / 100;
         customPercentSlider.value = newSliderValue;
      
         // slider Thumb moved; update customTipPercent
         customTipPercent = newSliderValue;
      } // end else
   
      // calculate customTip
      float customTip = customTipPercent * newTotal;
   
      // update tipFieldCustom with the new custom tip value
      tipFieldCustom.text = [NSString stringWithFormat:@"%.02f", 
         customTip];
   
      // update totalFieldCustom
      totalFieldCustom.text =
         [NSString stringWithFormat:@"%.02f", customTip + newTotal];
   } // end if
   else // the method was called programmatically
   {
      toggle = YES; // the method will next be called by user interaction
   }
} // end method calculateTip:
@end // Controller's implementation

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

