// AirfareFinder.m
// Fetches tweets and parses them for information.
#import "AirfareFinder.h"

@implementation AirfareFinder

@synthesize delegate;

// creates a new connection to Twitter and performs the search
- (void)getAirfares
{
   airfares = [[NSMutableArray alloc] init]; // initialize airfares
   isAirfare = YES; // initialize isAirfare to YES
   
   // create a new TwitterConnection
   TwitterConnection *connection = [[TwitterConnection alloc] init];
   connection.delegate = self; // set the TwitterConnection's delegate
   [connection performSearch:@"from:jetbluecheeps"]; // search for tweets
   [connection release]; // release the connection TwitterConnection
} // end method getAirfares

// called when the TwitterConnection receives all the data from Twitter
- (void)twitterConnection:(TwitterConnection *)connection
   didReceiveData:(NSData *)data
{
   // create a new NSXMLParser with the given data
   NSXMLParser *parser = [[NSXMLParser alloc] initWithData:data];
   parser.delegate = self; // set the parser's delegate to this object
   [parser parse]; // begin parsing the data
   [parser release]; // release the parser NSXMLParser
} // end method twitterConnection:didRecieveData:

// called when the NSXMLParser begins a new XML element
- (void)parser:(NSXMLParser *)parser didStartElement:
(NSString *)elementName namespaceURI:(NSString *)namespaceURI
 qualifiedName:(NSString *)qualifiedName attributes:
(NSDictionary *)attributeDict
{
   // if the parser found a <entry> tag
   if ([elementName isEqualToString:@"entry"])
   {
      currentAirfare = [[Airfare alloc] init]; // initialize new Airfare
      isAirfare = YES; // initialize isAirfare to YES
   } // end if
   
   // if the parser found a <content> tag
   else if ([elementName isEqualToString:@"content"])
            
      // initialize currentString with a capacity of 50
      currentString = [[NSMutableString alloc] initWithCapacity:50];
} // end parser:didStartElement:namespaceURI:qualifiedName:attributes:

// called when the NSXMLParser ends an XML tag
- (void)parser:(NSXMLParser *)parser didEndElement:(NSString *)elementName
  namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName
{
   // if the parser found a </entry> tag
   if ([elementName isEqualToString:@"entry"])
   {
      // if the current entry is an airfare
      if (isAirfare)
         [airfares addObject:currentAirfare]; // add object to airfares
      [currentAirfare release]; // release the currentAirfare Airfare
      currentAirfare = nil; // assign currentAirfare a value of nil
   } // end if
   
   // if the parser found a </content> tag
   else if ([elementName isEqualToString:@"content"])
   {
      // find the entire tweet minus the link at the end
      currentAirfare.tweet = [currentString removeLink];
      
      // find how much the flight costs from the tweet
      currentAirfare.cost = [currentString parseCost];
      
      // if the tweet didn't include a price
      if (currentAirfare.cost == nil)
         isAirfare = NO; // this tweet is not an airfare
      
      // get the origin and destination from the tweet
      NSArray *locations = [currentString parseLocations];
      
      // assign the origin and destination to the Airfare
      currentAirfare.origin = [locations objectAtIndex:0];
      currentAirfare.destination = [locations objectAtIndex:1];
   } // end else
   
   // if the parser found a </feed> tag
   else if ([elementName isEqualToString:@"feed"])
      // pass the found airfares to the delegate
      [delegate airfareFinder:self didFindAirfares:
         [airfares autorelease]];
   
   [currentString release]; // release the currentString NSMutableString
   currentString = nil; // assign currentString a value of nil
} // end method parser:didEndElement:namespaceURI:qualifiedName:

// called when the NSXMLParser finds characters inside an element
- (void)parser:(NSXMLParser *)parser foundCharacters:(NSString *)string
{
   // if currentString has been initialized
   if (currentString != nil)
      
      // append the found characters to currentString
      [currentString appendString:string];
} // end method parser:foundCharacters:
@end

@implementation NSString (parsing) // begin category parsing of NSString

// returns the cost of the airfare, if one is found
- (NSString *)parseCost
{
   // get the index of the $ sign
   int index = [self rangeOfString:@"$"].location;
   int i = index + 1; // initalize i
   BOOL found = NO; // initalize found to NO
   
   // while a character other than a digit hasn’t been found
   while (!found && i < self.length)
   {
      char c = [self characterAtIndex:i]; // get the character at index i
      
      // if the character is not a digit
      if (c <= '0' || c >= '9')
         found = YES; // a non-digit has been found
      
      ++i; // increment i
   } // end while
   
   NSString *cost = nil; // initialize cost to nil
   
   // if a dollar sign was found
   if (index < self.length)
      // get the $ plus the digits
      cost = [self substringWithRange:NSMakeRange(index, i - index)];
   
   return cost; // return the result
} // end method parseCost

// return the origin and destination of the airfare
- (NSArray *)parseLocations
{
   // initialize origin and destination to nil
   NSString *origin = nil, *destination = nil;
   int capitalCount = 0; // found zero capital letters so far
   
   // iterate through each character in the string
   for (int i = 0; i < self.length; i++)
   {
      char c = [self characterAtIndex:i]; // get the character at index i
      
      // if the character is a capital letter
      if (c >= 'A' && c <= 'Z')
         ++capitalCount; // increment capitalCount
      else
         capitalCount = 0; // reset capitalCount
      
      // if 3 sequential capital letters have been found
      if (capitalCount == 3)
      {
         // if an origin hasn't been found yet
         if (origin == nil)
            // assign the three capital letters to origin
            origin = [self substringWithRange:NSMakeRange(i - 2, 3)];
         
         // if a destination hasn't been found yet
         else if (destination == nil)
            // assign the three capital letters to destination
            destination = [self substringWithRange:NSMakeRange(i - 2, 3)];
         
         capitalCount = 0; // reset capitalCount
      } // end if
   } // end for
   
   NSArray *locations = nil; // initalize locations to nil
   
   // if both a origin and a destination were found
   if (origin != nil && destination != nil)
      // create locations with the origin and destination
      locations = [NSArray arrayWithObjects:origin, destination, nil];
   
   return locations; // return the found locations or nil
} // end method parseLocations

// removes the part of the tweet containing a link
- (NSString *)removeLink
{
   // find the location of the link
   int index = [self rangeOfString:@"<a href="].location;
   NSString *substring = nil; // initalize substring to nil
   
   // if a link was found
   if (index < self.length)
      // create substring that doesn't include the link
      substring = [self substringWithRange:NSMakeRange(0, index - 3)];
   
   return substring; // return the substring
} // end method removeLink
@end // end catagory parsing of class NSString


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

