// RootViewController.m
// The controller for the root view of the TwitterAirfares app.
#import "RootViewController.h"
#import "WebViewController.h"

static const int rowHeight = 117; // the height of each row in the table

@implementation RootViewController

@synthesize airfares; // generate get and set methods for airfares

// called when the main view finishes loading
- (void)viewDidLoad
{
   [super viewDidLoad]; // call the superclass's viewDidLoad method
   self.tableView.rowHeight = rowHeight; // set the table's row height
   
   // create activityView
   activityView = [[UIActivityIndicatorView alloc] initWithFrame:
      CGRectMake(0, 0, 20, 20)];
   
   airfareFinder = [[AirfareFinder alloc] init]; // create airfareFinder
   airfareFinder.delegate = self; // set airfareFinder's delegate
   [self refreshFares]; // refresh the list of fares
} // end method viewDidLoad

- (void)refreshFares
{
   // create a button to display the activity indicator
   UIBarButtonItem *activityButton =
      [[UIBarButtonItem alloc] initWithCustomView:activityView];
   
   // place the button on the left side of the bar
   self.navigationItem.leftBarButtonItem = activityButton;
   [activityButton release]; // release the activitybutton UIBarButtonItem
   [activityView startAnimating]; // start the activity view spinning
   [airfareFinder getAirfares]; // get the new list of airfares
} // end method refreshFares

// delegate method of AirfareFinder, called when it finds airfares
- (void)airfareFinder:(AirfareFinder *)finder
   didFindAirfares:(NSArray *)fares
{
   self.airfares = fares; // update airfares with the new items
   [activityView stopAnimating]; // stop the activity view spinning
   
   // create a new button to replace the activity view
   UIBarButtonItem *refreshButton = [[UIBarButtonItem alloc]
      initWithBarButtonSystemItem:UIBarButtonSystemItemRefresh target:self
      action:@selector(refreshFares)];
   
   // place the new button in place of the activit view
   self.navigationItem.leftBarButtonItem = refreshButton;
   [refreshButton release]; // release the refreshButton UIBarButtonItem
   [self.tableView reloadData]; // refresh table to display new entries
} // end method airfareFinder:didFindAirfares:

// called by the table view to find how many rows are in a given section
- (NSInteger)tableView:(UITableView *)tableView
   numberOfRowsInSection:(NSInteger)section
{
   return airfares.count; // return the number of total airfares
} // end method tableView:numberOfRowsInSection:

// called by the table view to get a cell for the given index path
- (UITableViewCell *)tableView:(UITableView *)tableView
   cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
   static NSString *CellIdentifier = @"AirfareCell";
   
   // get an AirfareCell by reusing an old one
   AirfareCell *cell = (AirfareCell *)
      [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
   
   // if there weren't any cells available for reuse
   if (cell == nil)
      
      // create a new AirfareCell
      cell = [[[AirfareCell alloc] initWithStyle:
         UITableViewCellStyleDefault reuseIdentifier:CellIdentifier]
         autorelease];
   
   // get the Airfare object for the cell at the given index
   Airfare *fare = [airfares objectAtIndex:indexPath.row];
   
   // set all the labels on the cell to correspond with the Airfare
   cell.originLabel.text = fare.origin; // set the origin label
   cell.destinationLabel.text = fare.destination; // set destination label
   cell.priceLabel.text = fare.cost; // set the price label
   cell.tweetLabel.text = fare.tweet; // set the tweet label
   return cell; // return the configured cell
} // end method tableView:cellForRowAtIndexPath:

// called when the user touches a cell
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:
   (NSIndexPath *)indexPath
{
   // create a new WebViewController
   WebViewController *controller = [[WebViewController alloc]
      initWithNibName:@"WebViewController" bundle:nil];
   
   // show the controller
   [self.navigationController pushViewController:controller animated:YES];
   [controller release]; // release the contorller WebViewController
} // end method tableView:didSelectRowAtIndexPath:

// release the RootViewController's memory
- (void)dealloc
{
   [airfareFinder release]; // release the airfareFinder AirfareFinder
   [airfares release]; // release the airfares NSMutableArray
   [activityView release]; // release activityView
   [super dealloc]; // call the superclass's dealloc method
} // end method dealloc
@end

/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

