// TwitterConnection.m
// Implementation of class TwitterConnection
#import "TwitterConnection.h"

@implementation TwitterConnection

@synthesize delegate; // generate get and set methods for delegate

- (void)performSearch:(NSString *)search
{
   // encode the search string with percent escapes
   search = [search stringByAddingPercentEscapesUsingEncoding:
      NSUTF8StringEncoding];
   
   // create the NSURL for performing the specified search
   NSURL *searchURL = [NSURL URLWithString:[NSString stringWithFormat:
      @"http://search.twitter.com/search.atom?q=%@", search]];
   
   // create an NSURLRequest from the created NSURL
   NSURLRequest *request = [[NSURLRequest alloc] initWithURL:searchURL];
   
   // create an NSURLConnection object with the created NSURLRequest
   NSURLConnection *connection =
      [[NSURLConnection alloc] initWithRequest:request delegate:self];
   [request release]; // release the request NSURLRequest
   
   // if the NSURLConnection was successfully created
   if (connection)
   {
      // create recieved data
      receivedData = [[NSMutableData data] retain];
      
      // display the standard network activity indicator in the status bar
      [UIApplication sharedApplication].networkActivityIndicatorVisible =
         YES;
   } // end if
   else
      NSLog(@"search \"%@\" could not be performed", search);
} // end method performSearch:

// called when the NSURLConnection receives a response to the connection
- (void)connection:(NSURLConnection *)connection
   didReceiveResponse:(NSURLResponse *)response
{
   receivedData.length = 0; // reset the data
} // end method connection:didRecieveResponse:

// called when the NSURLConnection receives data
- (void)connection:(NSURLConnection *)connection
   didReceiveData:(NSData *)data
{
   [receivedData appendData:data]; // append the data to receivedData
} // end method connection:didRecieveData:

// called when the NSURLConnection fails
- (void)connection:(NSURLConnection *)connection
  didFailWithError:(NSError *)error
{
   [receivedData release]; // release the receivedData NSMutableData
   [connection release]; // release the connection NSURLConnection
} // end method connection:didFailWithError:

// called when the NSURLConnection finishes
- (void)connectionDidFinishLoading:(NSURLConnection *)connection
{
   // hide the network activity indicator in the status bar
   [UIApplication sharedApplication].networkActivityIndicatorVisible = NO;
   
   // pass the received data to the delegate
   [delegate twitterConnection:self didReceiveData:receivedData];
   [receivedData release]; // release the receivedData NSMutableData
   [connection release]; // release the connection NSURLConnection
} // end method connectionDidFinishLoading:
@end


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

