// Fig. 14.15: NameRecordingViewController.m
// Implementation of NameRecordingViewController
#import "NameRecordingViewController.h"

@implementation NameRecordingViewController

@synthesize delegate; // synthesize get and set methods for the delegate
@synthesize textField; // synthesize get and set methods for textField

// called when the View finishes loading
- (void)viewDidLoad
{
   [super viewDidLoad]; // calls the superclass's viewDidLoad method
   [textField becomeFirstResponder]; // show the keyboard
} // end method viewDidLoad

// call when the user touches the "Done" button on the keyboard
- (IBAction)finishedNaming:sender
{
   // inform the delegate that the user chose a name
   [delegate nameRecordingViewController:self didGetName:textField.text];
} // end method finishedNaming:

// called every time the user edits text in the text field
- (BOOL)textField:(UITextField *)field shouldChangeCharactersInRange:
(NSRange)range replacementString:(NSString *)string
{
   // string that will exist once this method returns YES
   NSString *newString = [field.text stringByReplacingCharactersInRange:
      range withString:string];
   
   // create a new predicate that matches characters valid for file names
   NSPredicate *regex = [NSPredicate predicateWithFormat:
      @"SELF MATCHES '.*[^-_.a-zA-Z0-9].*'"];
   BOOL matches = [regex evaluateWithObject:newString]; // check for match
   
   // if the new string is an invalid file name
   if (matches)
      field.textColor = [UIColor redColor]; // change the text to red
   else // if the string is a valid file name
      field.textColor = [UIColor blackColor]; // change the text to black
   
   return YES; // allow the edit
} // end method textField:shouldChangeCharactersInRange:replacementString:

// called when the user touches the "Done" button on the keyboard
- (BOOL)textFieldShouldReturn:(UITextField *)field
{
   // create a new predicate that matches characters valid for file names
   NSPredicate *regex = [NSPredicate predicateWithFormat:
                         @"SELF MATCHES '.*[^-_.a-zA-Z0-9].*'"];
   return (![regex evaluateWithObject:field.text]); // check for a match
} // end method textFieldShouldReturn:
@end // NameRecoringViewController implementation


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

