// Fig. 14.20: PlaybackViewController.h
// Controls the View where the user plays existing sound files.
#import <UIKit/UIKit.h>
#import <MessageUI/MessageUI.h>

@protocol PlaybackViewControllerDelegate;

// begin interface PlaybackViewController's declaration
@interface PlaybackViewController : UIViewController
<UITableViewDataSource, UITableViewDelegate,
MFMailComposeViewControllerDelegate>
{
   id <PlaybackViewControllerDelegate> delegate; // this class's delegate
   IBOutlet UITableView *table; // displays a list of recordings
   IBOutlet UIToolbar *toolbar; // top toolbar
   IBOutlet UISlider *progressSlider; // controls the playback progress
   IBOutlet UISlider *volumeSlider; // controls the playback volume
   IBOutlet UIBarButtonItem *timeLabel; // shows the playback time
   IBOutlet UIBarButtonItem *playButton; // button to play/pause playback
   AVAudioPlayer *player; // plays the recordings
   NSMutableArray *files; // a list of the recordings
   NSTimer *timer; // fires to update the progress slider and time label
} // end instance variable declaration

// declare delegate and the outlets as properties
@property(nonatomic, assign) id <PlaybackViewControllerDelegate> delegate;
@property (nonatomic, retain) UITableView *table;
@property (nonatomic, retain) UIToolbar *toolbar;
@property (nonatomic, retain) UISlider *progressSlider;
@property (nonatomic, retain) UISlider *volumeSlider;
@property (nonatomic, retain) UIBarButtonItem *timeLabel;
@property (nonatomic, retain) UIBarButtonItem *playButton;

- (IBAction)sliderMoved:sender; // called when progressSlider is moved
- (IBAction)togglePlay:sender; // called when playButton is touched
- (IBAction)updateVolume:sender; // called when volumeSlider is moved
- (IBAction)record:sender; // called when the "record" button is touched
- (void)timerFired:(NSTimer *)t; // called when the timer fires
- (void)playSound; // plays the current sound
- (void)stopSound; // stops playback
@end // end interface PlaybackViewController

@protocol PlaybackViewControllerDelegate

// informs the delegate that the user finished playback
- (void)playbackViewControllerDidFinish:
(PlaybackViewController *)controller;
@end // end protocol PlaybackControllerDelegate


/**************************************************************************
 * (C) Copyright 2010 by Deitel & Associates, Inc. All Rights Reserved.   *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *                                                                        *
 * As a user of the book, Deitel & Associates, Inc. grants you the        *
 * nonexclusive right to copy, distribute, display the code, and create   *
 * derivative apps based on the code for noncommercial purposes only--so  *
 * long as you attribute the code to Deitel & Associates, Inc. and        *
 * reference www.deitel.com/books/iPhoneFP/. If you have any questions,   *
 * or specifically would like to use our code for commercial purposes,    *
 * contact deitel@deitel.com.                                             *
 *************************************************************************/

